/****************************************************************************
** Meta object code from reading C++ file 'resultsmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../krunner-6.25.0/src/model/resultsmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'resultsmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7KRunner12ResultsModelE_t {};
} // unnamed namespace

template <> constexpr inline auto KRunner::ResultsModel::qt_create_metaobjectdata<qt_meta_tag_ZN7KRunner12ResultsModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KRunner::ResultsModel",
        "queryStringChanged",
        "",
        "queryString",
        "favoriteIdsChanged",
        "limitChanged",
        "queryingChanged",
        "singleRunnerChanged",
        "runnerManagerChanged",
        "queryStringChangeRequested",
        "pos",
        "clear",
        "run",
        "QModelIndex",
        "idx",
        "runAction",
        "actionNumber",
        "getMimeData",
        "QMimeData*",
        "limit",
        "querying",
        "singleRunner",
        "singleRunnerMetaData",
        "KPluginMetaData",
        "runnerManager",
        "KRunner::RunnerManager*",
        "favoriteIds",
        "Roles",
        "IdRole",
        "CategoryRelevanceRole",
        "RelevanceRole",
        "EnabledRole",
        "CategoryRole",
        "SubtextRole",
        "ActionsRole",
        "MultiLineRole",
        "UrlsRole",
        "QueryMatchRole",
        "FavoriteIndexRole",
        "FavoriteCountRole"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'queryStringChanged'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'favoriteIdsChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'limitChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'queryingChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'singleRunnerChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'runnerManagerChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'queryStringChangeRequested'
        QtMocHelpers::SignalData<void(const QString &, int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Int, 10 },
        }}),
        // Method 'clear'
        QtMocHelpers::MethodData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'run'
        QtMocHelpers::MethodData<bool(const QModelIndex &)>(12, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Method 'runAction'
        QtMocHelpers::MethodData<bool(const QModelIndex &, int)>(15, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 13, 14 }, { QMetaType::Int, 16 },
        }}),
        // Method 'getMimeData'
        QtMocHelpers::MethodData<QMimeData *(const QModelIndex &) const>(17, 2, QMC::AccessPublic, 0x80000000 | 18, {{
            { 0x80000000 | 13, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'queryString'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'limit'
        QtMocHelpers::PropertyData<int>(19, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet, 2),
        // property 'querying'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'singleRunner'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'singleRunnerMetaData'
        QtMocHelpers::PropertyData<KPluginMetaData>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'runnerManager'
        QtMocHelpers::PropertyData<KRunner::RunnerManager*>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'favoriteIds'
        QtMocHelpers::PropertyData<QStringList>(26, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Roles'
        QtMocHelpers::EnumData<enum Roles>(27, 27, QMC::EnumFlags{}).add({
            {   28, Roles::IdRole },
            {   29, Roles::CategoryRelevanceRole },
            {   30, Roles::RelevanceRole },
            {   31, Roles::EnabledRole },
            {   32, Roles::CategoryRole },
            {   33, Roles::SubtextRole },
            {   34, Roles::ActionsRole },
            {   35, Roles::MultiLineRole },
            {   36, Roles::UrlsRole },
            {   37, Roles::QueryMatchRole },
            {   38, Roles::FavoriteIndexRole },
            {   39, Roles::FavoriteCountRole },
        }),
    };
    return QtMocHelpers::metaObjectData<ResultsModel, qt_meta_tag_ZN7KRunner12ResultsModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KRunner::ResultsModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QSortFilterProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KRunner12ResultsModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KRunner12ResultsModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7KRunner12ResultsModelE_t>.metaTypes,
    nullptr
} };

void KRunner::ResultsModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ResultsModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->queryStringChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->favoriteIdsChanged(); break;
        case 2: _t->limitChanged(); break;
        case 3: _t->queryingChanged(); break;
        case 4: _t->singleRunnerChanged(); break;
        case 5: _t->runnerManagerChanged(); break;
        case 6: _t->queryStringChangeRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 7: _t->clear(); break;
        case 8: { bool _r = _t->run((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->runAction((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { QMimeData* _r = _t->getMimeData((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QMimeData**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ResultsModel::*)(const QString & )>(_a, &ResultsModel::queryStringChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResultsModel::*)()>(_a, &ResultsModel::favoriteIdsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResultsModel::*)()>(_a, &ResultsModel::limitChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResultsModel::*)()>(_a, &ResultsModel::queryingChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResultsModel::*)()>(_a, &ResultsModel::singleRunnerChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResultsModel::*)()>(_a, &ResultsModel::runnerManagerChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResultsModel::*)(const QString & , int )>(_a, &ResultsModel::queryStringChangeRequested, 6))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KRunner::RunnerManager* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->queryString(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->limit(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->querying(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->singleRunner(); break;
        case 4: *reinterpret_cast<KPluginMetaData*>(_v) = _t->singleRunnerMetaData(); break;
        case 5: *reinterpret_cast<KRunner::RunnerManager**>(_v) = _t->runnerManager(); break;
        case 6: *reinterpret_cast<QStringList*>(_v) = _t->favoriteIds(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setQueryString(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setLimit(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setSingleRunner(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setRunnerManager(*reinterpret_cast<KRunner::RunnerManager**>(_v)); break;
        case 6: _t->setFavoriteIds(*reinterpret_cast<QStringList*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 1: _t->resetLimit(); break;
        default: break;
        }
    }
}

const QMetaObject *KRunner::ResultsModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KRunner::ResultsModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KRunner12ResultsModelE_t>.strings))
        return static_cast<void*>(this);
    return QSortFilterProxyModel::qt_metacast(_clname);
}

int KRunner::ResultsModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSortFilterProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void KRunner::ResultsModel::queryStringChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KRunner::ResultsModel::favoriteIdsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KRunner::ResultsModel::limitChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KRunner::ResultsModel::queryingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KRunner::ResultsModel::singleRunnerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KRunner::ResultsModel::runnerManagerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KRunner::ResultsModel::queryStringChangeRequested(const QString & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}
QT_WARNING_POP
