/****************************************************************************
** Meta object code from reading C++ file 'runnermanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../krunner-6.25.0/src/runnermanager.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'runnermanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7KRunner13RunnerManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto KRunner::RunnerManager::qt_create_metaobjectdata<qt_meta_tag_ZN7KRunner13RunnerManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KRunner::RunnerManager",
        "matchesChanged",
        "",
        "QList<KRunner::QueryMatch>",
        "matches",
        "queryFinished",
        "queryingChanged",
        "requestUpdateQueryString",
        "term",
        "cursorPosition",
        "historyEnabledChanged",
        "historyChanged",
        "setupMatchSession",
        "matchSessionComplete",
        "launchQuery",
        "runnerId",
        "reset",
        "setHistoryEnvironmentIdentifier",
        "identifier",
        "removeFromHistory",
        "index",
        "getHistorySuggestion",
        "typedQuery",
        "onMatchesChanged",
        "history",
        "querying",
        "historyEnabled"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'matchesChanged'
        QtMocHelpers::SignalData<void(const QList<KRunner::QueryMatch> &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'queryFinished'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'queryingChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestUpdateQueryString'
        QtMocHelpers::SignalData<void(const QString &, int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::Int, 9 },
        }}),
        // Signal 'historyEnabledChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'historyChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setupMatchSession'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'matchSessionComplete'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'launchQuery'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::QString, 15 },
        }}),
        // Slot 'launchQuery'
        QtMocHelpers::SlotData<void(const QString &)>(14, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Slot 'reset'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setHistoryEnvironmentIdentifier'
        QtMocHelpers::SlotData<void(const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 },
        }}),
        // Method 'removeFromHistory'
        QtMocHelpers::MethodData<void(int)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Method 'getHistorySuggestion'
        QtMocHelpers::MethodData<QString(const QString &) const>(21, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 22 },
        }}),
        // Method 'onMatchesChanged'
        QtMocHelpers::MethodData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'history'
        QtMocHelpers::PropertyData<QStringList>(24, QMetaType::QStringList, QMC::DefaultPropertyFlags, 5),
        // property 'querying'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'historyEnabled'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<RunnerManager, qt_meta_tag_ZN7KRunner13RunnerManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KRunner::RunnerManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KRunner13RunnerManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KRunner13RunnerManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7KRunner13RunnerManagerE_t>.metaTypes,
    nullptr
} };

void KRunner::RunnerManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RunnerManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->matchesChanged((*reinterpret_cast<std::add_pointer_t<QList<KRunner::QueryMatch>>>(_a[1]))); break;
        case 1: _t->queryFinished(); break;
        case 2: _t->queryingChanged(); break;
        case 3: _t->requestUpdateQueryString((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 4: _t->historyEnabledChanged(); break;
        case 5: _t->historyChanged(); break;
        case 6: _t->setupMatchSession(); break;
        case 7: _t->matchSessionComplete(); break;
        case 8: _t->launchQuery((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 9: _t->launchQuery((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->reset(); break;
        case 11: _t->setHistoryEnvironmentIdentifier((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->removeFromHistory((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: { QString _r = _t->getHistorySuggestion((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->onMatchesChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (RunnerManager::*)(const QList<KRunner::QueryMatch> & )>(_a, &RunnerManager::matchesChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (RunnerManager::*)()>(_a, &RunnerManager::queryFinished, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (RunnerManager::*)()>(_a, &RunnerManager::queryingChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (RunnerManager::*)(const QString & , int )>(_a, &RunnerManager::requestUpdateQueryString, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (RunnerManager::*)()>(_a, &RunnerManager::historyEnabledChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (RunnerManager::*)()>(_a, &RunnerManager::historyChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->history(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->querying(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->historyEnabled(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setHistoryEnabled(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KRunner::RunnerManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KRunner::RunnerManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KRunner13RunnerManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KRunner::RunnerManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void KRunner::RunnerManager::matchesChanged(const QList<KRunner::QueryMatch> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KRunner::RunnerManager::queryFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KRunner::RunnerManager::queryingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KRunner::RunnerManager::requestUpdateQueryString(const QString & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void KRunner::RunnerManager::historyEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KRunner::RunnerManager::historyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
